Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BareGitRepo ¶
BareGitRepo creates a temporary bare git repository for testing. Returns the path to the bare repo. To make it non-empty (cloneable), a temporary working copy is created with an initial commit.
func TempHakoHome ¶
TempHakoHome creates a temporary ~/.hako/ structure and sets HAKO_HOME. Returns the hako home path. Cleanup is automatic via t.TempDir().
func TestAgeIdentity ¶
TestAgeIdentity generates a test age keypair. Returns the identity (secret key) and recipient (public key) strings.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.